/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtubeAnalytics.model;

import com.google.api.client.json.GenericJson;

/**
 * Contains a single result table. The table is returned as an array of rows that contain the values
 * for the cells of the table. Depending on the metric or dimension, the cell can contain a string
 * (video ID, country code) or a number (number of views or number of likes).
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Analytics API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ResultTable extends GenericJson {

  /**
   * This value specifies information about the data returned in the rows fields. Each item in the
   * columnHeaders list identifies a field returned in the rows value, which contains a list of
   * comma-delimited data. The columnHeaders list will begin with the dimensions specified in the
   * API request, which will be followed by the metrics specified in the API request. The order of
   * both dimensions and metrics will match the ordering in the API request. For example, if the API
   * request contains the parameters dimensions=ageGroup,gender=viewerPercentage, the API response
   * will return columns in this order: ageGroup,gender,viewerPercentage.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<ColumnHeaders> columnHeaders;

  static {
    // hack to force ProGuard to consider ColumnHeaders used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(ColumnHeaders.class);
  }

  /**
   * This value specifies the type of data included in the API response. For the query method, the
   * kind property value will be youtubeAnalytics#resultTable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The list contains all rows of the result table. Each item in the list is an array that contains
   * comma-delimited data corresponding to a single row of data. The order of the comma-delimited
   * data fields will match the order of the columns listed in the columnHeaders field. If no data
   * is available for the given query, the rows element will be omitted from the response. The
   * response for a query with the day dimension will not contain rows for the most recent days.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.util.List<Object>> rows;

  /**
   * This value specifies information about the data returned in the rows fields. Each item in the
   * columnHeaders list identifies a field returned in the rows value, which contains a list of
   * comma-delimited data. The columnHeaders list will begin with the dimensions specified in the
   * API request, which will be followed by the metrics specified in the API request. The order of
   * both dimensions and metrics will match the ordering in the API request. For example, if the API
   * request contains the parameters dimensions=ageGroup,gender=viewerPercentage, the API response
   * will return columns in this order: ageGroup,gender,viewerPercentage.
   * The value returned may be {@code null}.
   */
  public java.util.List<ColumnHeaders> getColumnHeaders() {
    return columnHeaders;
  }

  /**
   * This value specifies information about the data returned in the rows fields. Each item in the
   * columnHeaders list identifies a field returned in the rows value, which contains a list of
   * comma-delimited data. The columnHeaders list will begin with the dimensions specified in the
   * API request, which will be followed by the metrics specified in the API request. The order of
   * both dimensions and metrics will match the ordering in the API request. For example, if the API
   * request contains the parameters dimensions=ageGroup,gender=viewerPercentage, the API response
   * will return columns in this order: ageGroup,gender,viewerPercentage.
   * The value set may be {@code null}.
   */
  public ResultTable setColumnHeaders(java.util.List<ColumnHeaders> columnHeaders) {
    this.columnHeaders = columnHeaders;
    return this;
  }

  /**
   * This value specifies the type of data included in the API response. For the query method, the
   * kind property value will be youtubeAnalytics#resultTable.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * This value specifies the type of data included in the API response. For the query method, the
   * kind property value will be youtubeAnalytics#resultTable.
   * The value set may be {@code null}.
   */
  public ResultTable setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The list contains all rows of the result table. Each item in the list is an array that contains
   * comma-delimited data corresponding to a single row of data. The order of the comma-delimited
   * data fields will match the order of the columns listed in the columnHeaders field. If no data
   * is available for the given query, the rows element will be omitted from the response. The
   * response for a query with the day dimension will not contain rows for the most recent days.
   * The value returned may be {@code null}.
   */
  public java.util.List<java.util.List<Object>> getRows() {
    return rows;
  }

  /**
   * The list contains all rows of the result table. Each item in the list is an array that contains
   * comma-delimited data corresponding to a single row of data. The order of the comma-delimited
   * data fields will match the order of the columns listed in the columnHeaders field. If no data
   * is available for the given query, the rows element will be omitted from the response. The
   * response for a query with the day dimension will not contain rows for the most recent days.
   * The value set may be {@code null}.
   */
  public ResultTable setRows(java.util.List<java.util.List<Object>> rows) {
    this.rows = rows;
    return this;
  }

  /**
   * Model definition for ResultTableColumnHeaders.
   */
  public static final class ColumnHeaders extends GenericJson {

    /**
     * The type of the column (DIMENSION or METRIC).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String columnType;

    /**
     * The type of the data in the column (STRING, INTEGER, FLOAT, etc.).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String dataType;

    /**
     * The name of the dimension or metric.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String name;

    /**
     * The type of the column (DIMENSION or METRIC).
     * The value returned may be {@code null}.
     */
    public String getColumnType() {
      return columnType;
    }

    /**
     * The type of the column (DIMENSION or METRIC).
     * The value set may be {@code null}.
     */
    public ColumnHeaders setColumnType(String columnType) {
      this.columnType = columnType;
      return this;
    }

    /**
     * The type of the data in the column (STRING, INTEGER, FLOAT, etc.).
     * The value returned may be {@code null}.
     */
    public String getDataType() {
      return dataType;
    }

    /**
     * The type of the data in the column (STRING, INTEGER, FLOAT, etc.).
     * The value set may be {@code null}.
     */
    public ColumnHeaders setDataType(String dataType) {
      this.dataType = dataType;
      return this;
    }

    /**
     * The name of the dimension or metric.
     * The value returned may be {@code null}.
     */
    public String getName() {
      return name;
    }

    /**
     * The name of the dimension or metric.
     * The value set may be {@code null}.
     */
    public ColumnHeaders setName(String name) {
      this.name = name;
      return this;
    }

  }

}
